#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom Rcpp sourceCpp
#' @importFrom cli cli_abort cli_warn cli_inform
#' @importFrom purrr map map2 map_lgl map_if flatten flatten_dbl list_c is_null
#' @useDynLib epizootic, .registration = TRUE
## usethis namespace: end
utils::globalVariables(
  c(
    ".",
    "Day",
    "abundance_threshold",
    "breeding_season_length",
    "compare",
    "carrying_capacity",
    "compartments",
    "fecundity",
    "fecundity_mask",
    "fecundity_unit",
    "initial_vector",
    "mortality",
    "mortality_unit",
    "occupied_indices",
    "recovery",
    "recovery_mask",
    "recovery_unit",
    "stages",
    "time_steps",
    "tm",
    "transmission",
    "transmission_mask",
    "transmission_unit",
    "carrying_capacity_matrix",
    "carrying_capacity_t_max",
    "demographic_stochasticity",
    "density_stages",
    "dispersal",
    "dispersal_source_n_k",
    "dispersal_stages",
    "dispersal_target_k",
    "dispersal_target_n",
    "dispersal_target_n_k",
    "initial_abundance",
    "populations",
    "replicates",
    "results_breakdown",
    "results_selection",
    "s",
    "season_functions",
    "seasons",
    "segments",
    "simulation_order",
    "breeding_season_matrix",
    "breeding_season_t_max",
    "dispersal_functions",
    "dispersal_immigrant_map",
    "dispersal_segments",
    "dispersal_target_pop_map",
    "dispersal_type",
    "name",
    "occupied_dispersal_indices",
    "season_lengths",
    "segment_abundance",
    "SimulatorReference"
  )
)
